@@ -39,4 +39,9 @@ cat "${TMPFILE}" > "${CHANGELOG}"
 rm -f "${TMPFILE}"
 
 
-echo "updated ${CHANGELOG} from ${NEWS}!" 1>&2
+cat >&2 <<EOF
+updated ${CHANGELOG} from ${NEWS}!
+now run:
+
+git commit ${CHANGELOG} -m "Update d/upstream-changelog"
+EOF
